Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(218)

Unified Diff: chrome/browser/chromeos/drive/file_system/move_operation.h

Issue 12039005: drive: Deal with the root directory in the same way as others in MoveOperation. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/drive/file_system/move_operation.h
diff --git a/chrome/browser/chromeos/drive/file_system/move_operation.h b/chrome/browser/chromeos/drive/file_system/move_operation.h
index cf951669f4faadcec0a2bed24d4ccfe54d66ff1d..917222251d9d5e02a8b995a2c5de872f8018bfda 100644
--- a/chrome/browser/chromeos/drive/file_system/move_operation.h
+++ b/chrome/browser/chromeos/drive/file_system/move_operation.h
@@ -89,13 +89,13 @@ class MoveOperation {
//
// Can be called from UI thread. |callback| is run on the calling thread.
// |callback| must not be null.
- void RemoveEntryFromNonRootDirectory(const FileMoveCallback& callback,
- DriveFileError error,
- const FilePath& file_path);
+ void RemoveEntryFromDirectory(const FileMoveCallback& callback,
+ DriveFileError error,
+ const FilePath& file_path);
- // Part of RemoveEntryFromNonRootDirectory(). Called after
+ // Part of RemoveEntryFromDirectory(). Called after
// GetEntryInfoPairByPaths() is complete. |callback| must not be null.
- void RemoveEntryFromNonRootDirectoryAfterEntryInfoPair(
+ void RemoveEntryFromDirectoryAfterEntryInfoPair(
const FileMoveCallback& callback,
scoped_ptr<EntryInfoPairResult> result);
@@ -105,14 +105,14 @@ class MoveOperation {
//
// Can be called from UI thread. |callback| is run on the calling thread.
// |callback| must not be null.
- void MoveEntryFromRootDirectory(const FilePath& directory_path,
- const FileOperationCallback& callback,
- DriveFileError error,
- const FilePath& file_path);
+ void AddEntryToDirectory(const FilePath& directory_path,
+ const FileOperationCallback& callback,
+ DriveFileError error,
+ const FilePath& file_path);
- // Part of MoveEntryFromRootDirectory(). Called after
+ // Part of AddEntryToDirectory(). Called after
// GetEntryInfoPairByPaths() is complete. |callback| must not be null.
- void MoveEntryFromRootDirectoryAfterGetEntryInfoPair(
+ void AddEntryToDirectoryAfterGetEntryInfoPair(
const FileOperationCallback& callback,
scoped_ptr<EntryInfoPairResult> result);

Powered by Google App Engine
This is Rietveld 408576698